const config = require('config')
const last = require('lodash/last')

const statuses = config.get('statuses')

const updateStatusByRecommendation = async (collection, recommendation) => {
  let newStatus = 'pendingApproval'
  if (['minor', 'major'].includes(recommendation))
    newStatus = 'revisionRequested'
  collection.status = newStatus
  collection.visibleStatus = statuses[collection.status].private
  await collection.save()
}

const getFragmentAndAuthorData = async ({
  UserModel,
  FragmentModel,
  collection: { fragments, authors },
}) => {
  const fragment = await FragmentModel.find(last(fragments))
  let { title, abstract } = fragment.metadata
  title = title.replace(/<(.|\n)*?>/g, '')
  abstract = abstract ? abstract.replace(/<(.|\n)*?>/g, '') : ''

  const submittingAuthorData = authors.find(
    author => author.isSubmitting === true,
  )
  const submittingAuthor = await UserModel.find(submittingAuthorData.userId)
  const authorsPromises = authors.map(async author => {
    const user = await UserModel.find(author.userId)
    return `${user.firstName} ${user.lastName}`
  })
  const authorsList = await Promise.all(authorsPromises)
  const { id } = fragment
  return { title, submittingAuthor, id, abstract, authorsList }
}

const getAgreedReviewerInvitation = (invitations = []) =>
  invitations.filter(
    inv =>
      inv.role === 'reviewer' &&
      inv.hasAnswer === true &&
      inv.isAccepted === true,
  )

module.exports = {
  updateStatusByRecommendation,
  getFragmentAndAuthorData,
  getAgreedReviewerInvitation,
}
