process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0'
process.env.SUPPRESS_NO_CONFIG_WARNING = true

const httpMocks = require('node-mocks-http')
const fixtures = require('./../fixtures/fixtures')
const Model = require('./../helpers/Model')

const { standardCollection } = fixtures.collections
const { submittingAuthor } = fixtures.users

const getPath = '../../routes/collectionsUsers/get'
describe('Get collections users route handler', () => {
  it('should return success when the request data is correct', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = standardCollection.id
    req.user = submittingAuthor.id
    const res = httpMocks.createResponse()
    const models = Model.build()
    await require(getPath)(models)(req, res)

    expect(res.statusCode).toBe(200)
    const data = JSON.parse(res._getData())
    expect(data).toHaveLength(1)
    expect(data[0].isSubmitting).toBeDefined()
    expect(data[0].type).toBe('user')
  })
  it('should return an error when the collection does not exist', async () => {
    const req = httpMocks.createRequest()
    req.params.collectionId = 'invalid-id'
    req.user = submittingAuthor.id
    const res = httpMocks.createResponse()
    const models = Model.build()
    await require(getPath)(models)(req, res)
    expect(res.statusCode).toBe(404)
    const data = JSON.parse(res._getData())
    expect(data.error).toEqual('collection not found')
  })
})
